﻿//========================================================================================
// "Контроль последней строки абзаца"
//     (EndParagraphWords.js)
//
// Версия 2.2
//
//    Скрипт выполняет проверку количества символов в последней строке абзаца.
// Перед запуском необходимо выделить текстовый фрейм. Может выполняться проверка
// текста во всех фреймах, связанных с выделеным.
//    Сначала производится разгонка текста в абзаце пока в последней строке
// количество символов не превысит минимальное. Затем последнему слову в абзаце
// назначается атрибут "nobreak" и оно становиться непереносимым.
//    Написан, в-первую очередь, для работы в газете объявлений.
//    
// 2.0 Добавлена морда лица, возможность выбора цвета выделения обработанных слов,
//     указание обработки цепочки фреймов.
//
// 2.1 Добавлена возможность отключения контроля обработанных слов
// 
// 2.2 Добавлен выбор стиля проверяемых абзацев или всех
//
// Автор: Андрей Рыжков (ragman)
//
// Дата: 16.03.2005 г.
//
//=========================================================================================


// Устанавливаем переменные по-умолчанию
minChars = 7;          				// Минимальное количество символов в последней строке абзаца
myColorSelect = "red"; 				// Цвет выделения обработаных слов (должен присутствовать в палитре)
allTextFrames = false; 				// Обрабатывать цепочку связаных текстовых фреймов?
myControlColor = true; 				// Не производить контроль обработанных слов
myParagraphStyleNameSelect = "ОБЪЯВЛЕНИЯ";	// Стиль параграфа
myAllParagraphStyle = false;			// Все параграфы

with (app) {
//Проверяем, что у нас выделено
	if ((selection.length == 1)&&((selection[0].constructor.name == "TextFrame"))) {
	} else {
		alert("Необходимо вытелить один текстовый фрейм");
		exit();
	}
	
// Создаем список цветов в публикации
	var myColorSwatchesName = new Array();
	var mySelectIndexColor = 0;
	for (myCounter = 0; myCounter < activeDocument.swatches.length; myCounter++) {
		myColorSwatchesName[myCounter] = activeDocument.swatches.item(myCounter).name;
		if (myColorSwatchesName[myCounter] == myColorSelect) {
			mySelectIndexColor = myCounter;
		}
	}
	
// Создаем список стилей в публикации
	var myParagraphStyleName = new Array();
	var mySelectIndexParagraphStyle = 0;
	for (myCounter = 0; myCounter < activeDocument.paragraphStyles.length; myCounter++) {
		myParagraphStyleName[myCounter] = activeDocument.paragraphStyles.item(myCounter).name;
		if (myParagraphStyleName[myCounter] == myParagraphStyleNameSelect) {
			mySelectIndexParagraphStyle = myCounter;
		}

	}
	
// Создаем диалог
	var myDialog = dialogs.add({name:"Контроль последней строки параграфа v2.2"});
// Подготовка
	with (myDialog.dialogColumns.add()) {
		with (dialogRows.add().borderPanels.add().dialogColumns.add()) {
			with (dialogRows.add()) {
				staticTexts.add({staticLabel:"Обрабатывать параграфы стиля:"});
				var myDialogParagraphStyle = dropdowns.add({stringList:myParagraphStyleName, selectedIndex:mySelectIndexParagraphStyle});
				staticTexts.add({staticLabel:"или все"});
				var myDialogAllParagraphStyle = checkboxControls.add({});
				myDialogAllParagraphStyle.checkedState = myAllParagraphStyle;
			}
			with (dialogRows.add()) {
				staticTexts.add({staticLabel:"Минимальное количество символов в последней строке:"});
				var myDialogMinChars = integerEditboxes.add({editValue:minChars});
			}
			with (dialogRows.add()) {
				var myDialogAllTextFrames = checkboxControls.add({});
				myDialogAllTextFrames.checkedState = allTextFrames;
				staticTexts.add({staticLabel:"Обрабатывать связанные фреймы"});
			}
			with (dialogRows.add()) {
				var myDialogControlColor = checkboxControls.add({});
				myDialogControlColor.checkedState = myControlColor;
				staticTexts.add({staticLabel:"Не производить контроль"});
			}
			with (dialogRows.add()) {
				staticTexts.add({staticLabel:"Контрольный цвет:"});
				var myDialogColorSelect = dropdowns.add({stringList:myColorSwatchesName, selectedIndex:mySelectIndexColor});
			}
		}
		with (dialogRows.add()) {
			dialogColumns.add().staticTexts.add({staticLabel:"Андрей Рыжков     special946@gmail.com"});
		}
	}
// Показываем
	var myResult = myDialog.show();
	if (!myResult) {
		myDialog.destroy();
		exit();
	}
	myColorSelect = activeDocument.swatches.item(myDialogColorSelect.selectedIndex);
	minChars = myDialogMinChars.editContents;
	allTextFrames = myDialogAllTextFrames.checkedState;
	myControlColor = myDialogControlColor.checkedState;
	myParagraphStyle = activeDocument.paragraphStyles.item(myDialogParagraphStyle.selectedIndex);
	myAllParagraphStyle = myDialogAllParagraphStyle.checkedState;	

// Обрабатывать цепочку фреймов?
	if (allTextFrames) {
		var myStory = selection[0].parentStory;
	} else {
		var myStory = selection[0];
	}

// Для каждого абзаца текста
	for (myCounter = 0; myCounter < myStory.paragraphs.length; myCounter++) {
	   myPara = myStory.paragraphs[myCounter];
	   if (myAllParagraphStyle || myPara.appliedParagraphStyle == myParagraphStyle){
		lnCount = myPara.lines.length; //Количество строк в параграфе
		if (lnCount > 1) { //Если число строк в параграфе больше одной
			var myTextLine = myPara.lines[lnCount - 1]; //Последняя строка параграфа
			var NumberMyWordEndLine = myTextLine.words[0].index;
			var NumberMyParaWords = myPara.words.length;
			var myCountWords = myTextLine.words.length;
			myCharCount = myTextLine.characters.length;
			while (myCharCount <= minChars) {
				myPara.tracking = myPara.tracking + 10;
				myCharCount = myTextLine.characters.length;
			}
			if (myCountWords == 1) {
				if (!myControlColor) {
					myPara.words[NumberMyParaWords - 1].fillColor = myColorSelect; 	// Выделение обработанного слова
				}
				myPara.words[NumberMyParaWords - 1].noBreak = true;
			}
		}
	   }
	}
	if (!myControlColor) {
		alert("Проверяй...");
		for (myCounter = 0; myCounter < myStory.paragraphs.length; myCounter++) { // Соответственно возврат тексту черного цвета.
			myStory.paragraphs[myCounter].fillColor = "Black";
		}
	}
	alert("Готово!");
}